bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.delete
===============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.delete